@@ -27,7 +27,7 @@ PASS=0
 FAIL=1
 
 # eval command and check if expected = actual
-function assertEquals()
+function assertEqual()
 {
     actual="`eval $1`"
     expected=$2;
